#!/bin/bash
#
# ./build_tasks.sh [git repo | path]
#
# Unless tasks are specified, we'll look for them in:
#
#   1. /var/lib/bughunting/tasks
#
#   2. ./tasks # copied
#
#   3. https://gitlab.com/bughunting/tasks.git
#
#
# Optional
#   git repo	url to the git repo containing tasks
#   path	    custom path to the tasks
#

set -xe
bash -n "$0"

abort () {
  echo "Error:" "$@" >&2
  exit 1
}

# VARS
clone=
tasks=
tasks_dir='/var/lib/bughunting/tasks'
tasks_repo='https://gitlab.com/bughunting/tasks.git'

# ARGS
tasks="$1"
shift ||:

if [ -z "$tasks" ] ; then
  if [ -r "${tasks_dir}/Makefile" ]; then
  	tasks="$tasks_dir"

  elif [ -d "tasks" ]; then
  	tasks='tasks'

  else
  	clone="$tasks_repo"

  fi

elif [ -n "$(grep -E '^(https|ssh|git)\:\/\/' <<< "$tasks" ; grep -E '^git\@' <<< "$tasks")" ] ; then
	clone="$tasks"

fi

if [ -n "$clone" ] ; then
	# clone into folder named tasks
	git clone "$clone" tasks
  tasks=tasks
fi

cd "$tasks"

rm -rf rpm-build-dir
make rpms

rpm -q bughunting-tasks && re=re || re=

dnf ${re}install -y rpm-build-dir/*/bughunting-tasks-*.rpm

rpm -V bughunting-tasks
