#!/bin/bash

die () {
  echo -e "Error: " "$@" >&2
  exit 1
}

[[ -n "$SOURCES" ]] || die "Sources dir not set"
[[ -n "$KEY" ]] || die "You have to specify KEY environment variable, like so:\n\n  $ docker run -e KEY=????? ... \n"
[[ $(wc -c <<< "$KEY") -eq 17 ]] || die "KEY should have 16 characters. Please ask for help you don't know the KEY."

# Run only if SOURCES dir is empty
ls -d ${SOURCES}/*/ &>/dev/null || {

  mkdir -p "$SOURCES"

  tasks_dir="${TASKS:-/var/lib/bughunting/tasks}"
  ls -d ${tasks_dir}/*/ &>/dev/null || die "Invalid tasks dir: $tasks_dir"

  # guess from sources path: /home/USER/sources
  user="`cut -d'/' -f3 <<< "$SOURCES"`"
  grep -q "^$user:" /etc/passwd \
    && chown -R "$user:" "$SOURCES"

  cd "$tasks_dir"

  # Copy the installed tasks into the client's home
  for task_path in $(ls -d */); do
    task_name="$(basename "$task_path")"
    cp -r "${task_path}source" "${SOURCES}/$task_name"
  done
}

[[ $# -gt 0 ]] && exec "$@"

sleep infinity
